# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.llm_base_config_settings import LLMBaseConfigSettings

class TestLLMBaseConfigSettings(unittest.TestCase):
    """LLMBaseConfigSettings unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LLMBaseConfigSettings:
        """Test LLMBaseConfigSettings
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LLMBaseConfigSettings`
        """
        model = LLMBaseConfigSettings()
        if include_optional:
            return LLMBaseConfigSettings(
                timeout = 1.337,
                temperature = 1.337,
                top_p = 1.337,
                max_tokens = 56,
                stop = '',
                presence_penalty = 1.337,
                frequency_penalty = 1.337,
                seed = 56,
                logprobs = True,
                top_logprobs = 56,
                logit_bias = [
                    arthur_client.api_bindings.models.logit_bias_item.LogitBiasItem(
                        token_id = 56, 
                        bias = -100.0, )
                    ],
                max_completion_tokens = 56,
                reasoning_effort = 'none',
                thinking = arthur_client.api_bindings.models.anthropic_thinking_param.AnthropicThinkingParam(
                    type = 'enabled', 
                    budget_tokens = 56, )
            )
        else:
            return LLMBaseConfigSettings(
        )
        """

    def testLLMBaseConfigSettings(self):
        """Test LLMBaseConfigSettings"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.custom_aggregation_test_spec import CustomAggregationTestSpec

class TestCustomAggregationTestSpec(unittest.TestCase):
    """CustomAggregationTestSpec unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CustomAggregationTestSpec:
        """Test CustomAggregationTestSpec
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CustomAggregationTestSpec`
        """
        model = CustomAggregationTestSpec()
        if include_optional:
            return CustomAggregationTestSpec(
                reported_aggregations = [
                    arthur_client.api_bindings.models.reported_custom_aggregation.ReportedCustomAggregation(
                        metric_name = '', 
                        description = '', 
                        value_column = '', 
                        timestamp_column = '', 
                        metric_kind = 'sketch', 
                        dimension_columns = [
                            ''
                            ], )
                    ],
                aggregate_args = [
                    null
                    ],
                sql = '',
                name = '',
                description = '',
                aggregation_arg_configuration = [
                    arthur_client.api_bindings.models.metrics_arg_spec.MetricsArgSpec(
                        arg_key = '', 
                        arg_value = null, )
                    ],
                start_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                end_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                dataset_id = '',
                id = '',
                authored_by = arthur_client.api_bindings.models.user.User(
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    organization_id = '', 
                    id = '', 
                    first_name = '', 
                    last_name = '', 
                    email = '', 
                    picture = '', 
                    user_type = 'user', 
                    data_plane_id = '', 
                    client_id = '', 
                    organization_name = '', ),
                workspace_id = '',
                test_status = 'completed',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                job_id = ''
            )
        else:
            return CustomAggregationTestSpec(
                reported_aggregations = [
                    arthur_client.api_bindings.models.reported_custom_aggregation.ReportedCustomAggregation(
                        metric_name = '', 
                        description = '', 
                        value_column = '', 
                        timestamp_column = '', 
                        metric_kind = 'sketch', 
                        dimension_columns = [
                            ''
                            ], )
                    ],
                aggregate_args = [
                    null
                    ],
                sql = '',
                name = '',
                aggregation_arg_configuration = [
                    arthur_client.api_bindings.models.metrics_arg_spec.MetricsArgSpec(
                        arg_key = '', 
                        arg_value = null, )
                    ],
                start_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                end_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                dataset_id = '',
                id = '',
                authored_by = arthur_client.api_bindings.models.user.User(
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    organization_id = '', 
                    id = '', 
                    first_name = '', 
                    last_name = '', 
                    email = '', 
                    picture = '', 
                    user_type = 'user', 
                    data_plane_id = '', 
                    client_id = '', 
                    organization_name = '', ),
                workspace_id = '',
                test_status = 'completed',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                job_id = '',
        )
        """

    def testCustomAggregationTestSpec(self):
        """Test CustomAggregationTestSpec"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
